@@ -22,8 +22,9 @@ import re
 import threading
 import time
 
+from .Item import Item
+
 from .Connection import Connection
-from .Application import Application
 from .Events import Events
 from urllib3 import encode_multipart_formdata
 import configparser
@@ -178,9 +179,6 @@ class Device(Events):
         conf.read(self.__xpath_file)
         return conf.get(sop_id, key)
 
-    def application(self, sop_id, ui_app_id):
-        return Application(d=self, sop=sop_id, ui=ui_app_id)
-
     def refresh_layout(self):
         self.xmlStr = str(self.con.get(path="getLayoutXML").read(), 'utf-8')
 
@@ -189,6 +187,15 @@ class Device(Events):
 
     def serial_number(self):
         return self.__serialNumber
+    
+    def find_item_by_xpath_key(self, sopid, xpath_key):
+        i = Item(d=self, s=sopid, xpath=self.get_xpath(sopid, xpath_key))
+        return i
+
+    def find_item_by_xpath(self, sopid, xpath):
+        i = Item(d=self, s=sopid, xpath=xpath)
+        self.device.log("debug", "find_item_by_xpath(), find Item successful, %s" % (str(i)))
+        return i
 
     def log(self, level, text):
         pass
