@@ -49,25 +49,27 @@ class Item:
     __rotation = 0
     __clip = None
     device = None
-    app = None
+    sopid = ""
     __display_width = 0
     __display_height = 0
     rect = []
 
-    def __init__(self, d=None, a=None, node=None, xpath=""):
-        self.app = a
+    def __init__(self, d=None, s="", xpath=""):
+        self.sopid = s
         self.device = d
         self.__display_width = self.device.display_width()
         self.__display_height = self.device.display_height()
-        self.node = node
         self.xpath = xpath
-        self.__refresh_attribute()
+        self.__refresh_node()
+        if self.node is not None:
+            self.__refresh_attribute()
 
     def __refresh_node(self):
+        self.node = None
         self.device.refresh_layout()
         selector = etree.XML(self.device.xmlStr.encode('utf-8'))
         nodes = selector.xpath(self.xpath)
-        if len(nodes) > 0 and selector.get("sopId") == self.app.sopId:
+        if len(nodes) > 0 and selector.get("sopId") == self.sopid:
             self.node = nodes[0]
 
     def __refresh_attribute(self):
@@ -225,24 +227,25 @@ class Item:
         return False
 
     def __exist(self):
-        self.device.refresh_layout()
-        tree = xml.dom.minidom.parseString(self.device.xmlStr)
-        if tree.documentElement.getAttribute("sopId") == self.app.sopId:
-            image = []
-            for node in tree.documentElement.childNodes:
-                if node.childNodes[0].nodeName == "QQuickMouseArea" and node.childNodes[0].childNodes.length == 0:
-                    surface = node.childNodes[1]
-                else:
-                    surface = node.childNodes[0]
-                if len(image) == 0:
-                    image = self.__xml_tree_traversed(surface.childNodes, 1)
-                else:
-                    image = self.__img_cover(image, self.__xml_tree_traversed(surface.childNodes, 1))
-            # cv2.imshow(str(self.device.system_time()), image)
-            # cv2.waitKey(0)
-            b, g, r = cv2.split(image)
-            if len(np.argwhere(r == 255)) > 0:
-                return np.argwhere(r == 255)
+        self.__refresh_node()
+        if self.node is not None:
+            tree = xml.dom.minidom.parseString(self.device.xmlStr)
+            if tree.documentElement.getAttribute("sopId") == self.sopid:
+                image = []
+                for node in tree.documentElement.childNodes:
+                    if node.childNodes[0].nodeName == "QQuickMouseArea" and node.childNodes[0].childNodes.length == 0:
+                        surface = node.childNodes[1]
+                    else:
+                        surface = node.childNodes[0]
+                    if len(image) == 0:
+                        image = self.__xml_tree_traversed(surface.childNodes, 1)
+                    else:
+                        image = self.__img_cover(image, self.__xml_tree_traversed(surface.childNodes, 1))
+                # cv2.imshow(str(self.device.system_time()), image)
+                # cv2.waitKey(0)
+                b, g, r = cv2.split(image)
+                if len(np.argwhere(r == 255)) > 0:
+                    return np.argwhere(r == 255)
         return []
 
     def __xml_tree_traversed(self, nodes, fs):
